@@ -10,16 +10,16 @@ test_that("ecb_euro_rates works", {
   x <- ecb_euro_rates("latest")
   expect_named(x, c("date", "currency", "rate"))
   expect_identical(dim(x), c(30L, 3L))
-  expect_s3_class(x, "data.frame")
-  expect_s3_class(x$date, "Date")
+  expect_data_table(x)
+  expect_date(x$date)
   expect_vector(x$currency, character())
   expect_vector(x$rate, double())
 
   x <- ecb_euro_rates("history")
   expect_named(x, c("date", "currency", "rate"))
   expect_gt(nrow(x), 30L)
-  expect_s3_class(x, "data.frame")
-  expect_s3_class(x$date, "Date")
+  expect_data_table(x)
+  expect_date(x$date)
   expect_vector(x$currency, character())
   expect_vector(x$rate, double())
 })
